@@ -15,8 +15,8 @@ from typing import List, Dict, Union
 from ..broker import MessageBroker
 from ..bemcp.bemcp import MCPManager
 from ..utils import register_mcp_tools
-from ..aient.src.aient.models import chatgpt
-from ..aient.src.aient.plugins import get_function_call_list, registry
+from ..aient.aient.models import chatgpt
+from ..aient.aient.plugins import get_function_call_list, registry
 
 worker_system_prompt = """
 你是{name}。帮助用户头脑风暴。请分析不同用户的观点，并给出你的观点。
