@@ -201,6 +201,8 @@ class WorkerAgent(BaseAgent):
             self.broker.publish(message, self.error_topic)
         else:
             self.broker.publish({"status": "new_message", "result": "\n✅ 工作智能体:\n" + response}, self.status_topic)
+            if len(self.agent.conversation["default"]) > 1 and self.agent.conversation["default"][-1].role == "user":
+                self.agent.conversation["default"].pop(-1)
             self.broker.publish({
                 "conversation": self.agent.conversation["default"]
             }, self.publish_topic)
