@@ -1,4 +1,4 @@
-from ..aient.src.aient.plugins import register_tool
+from ..aient.aient.plugins import register_tool
 
 @register_tool()
 def task_complete(message: str) -> str:
@@ -14,4 +14,4 @@ def task_complete(message: str) -> str:
     Returns:
         str: 传入的任务完成信息。
     """
-    return "<task_complete_message>" + message + "</task_complete_message>"
+    return message
