@@ -21,11 +21,18 @@ def add_knowledge_node(parent_path: str, node_name: str, description: str = "",
     if tags:
         if "[" not in tags:
             if "," not in tags:
-                tags = f"['{tags}']"
+                if "#" in tags:
+                    tags = f"{tags.split('#')}"
+                else:
+                    if " " in tags:
+                        tags = f"{tags.split(' ')}"
+                    else:
+                        tags = f"['{tags}']"
             else:
                 tags = f"{tags.split(',')}"
+
         tags = ast.literal_eval(tags) if isinstance(tags, str) else tags
-        tags = [tag.strip().lstrip("#") for tag in tags]
+        tags = [tag.strip().lstrip("#") for tag in tags if tag.strip()]
     return kgm.add_node(parent_path, node_name, description, tags)
 
 @register_tool()
@@ -42,7 +49,13 @@ def add_tags_to_knowledge_node(node_path: str, tags: List[str]) -> str:
     """
     if "[" not in tags:
         if "," not in tags:
-            tags = f"['{tags}']"
+            if "#" in tags:
+                tags = f"{tags.split('#')}"
+            else:
+                if " " in tags:
+                    tags = f"{tags.split(' ')}"
+                else:
+                    tags = f"['{tags}']"
         else:
             tags = f"{tags.split(',')}"
 
@@ -64,7 +77,13 @@ def remove_tags_from_knowledge_node(node_path: str, tags: List[str]) -> str:
     """
     if "[" not in tags:
         if "," not in tags:
-            tags = f"['{tags}']"
+            if "#" in tags:
+                tags = f"{tags.split('#')}"
+            else:
+                if " " in tags:
+                    tags = f"{tags.split(' ')}"
+                else:
+                    tags = f"['{tags}']"
         else:
             tags = f"{tags.split(',')}"
 
@@ -143,3 +162,7 @@ def get_node_details(node_path: str) -> str:
         str: 包含节点详细信息的、格式化的文本字符串。
     """
     return kgm.get_node_details(node_path)
+
+if __name__ == "__main__":
+    print(add_knowledge_node(".", "1", "2", "#date: 2023-12-01 #source:官方频道"))
+# python -m beswarm.tools.graph
