@@ -1,8 +1,8 @@
 import os
-from ..aient.src.aient.plugins import register_tool, get_function_call_list
+from ..aient.aient.plugins import register_tool, get_function_call_list
 
-from ..aient.src.aient.models import chatgpt
-from ..aient.src.aient.prompt import planner_system_prompt
+from ..aient.aient.models import chatgpt
+from ..aient.aient.prompt import planner_system_prompt
 
 @register_tool()
 async def planner(goal, tools, work_dir):
