@@ -1,4 +1,4 @@
-from ..aient.src.aient.plugins import register_tool
+from ..aient.aient.plugins import register_tool
 
 @register_tool()
 def request_admin_input(prompt: str) -> str:
