@@ -1,7 +1,7 @@
 from datetime import datetime
 from typing import List, Dict, Union
 
-from ..core import mcp_manager, broker, task_manager, kgm
+from ..core import mcp_manager, broker, kgm, get_task_manager, current_task_manager, current_work_dir
 from ..agents.planact import BrokerWorker
 from ..agents.chatgroup import ChatGroupWorker
 from ..aient.aient.plugins import register_tool
@@ -10,6 +10,9 @@ from ..aient.aient.plugins import register_tool
 @register_tool()
 async def worker(goal: str, tools: List[Union[str, Dict]], work_dir: str, cache_messages: Union[bool, List[Dict]] = None):
     start_time = datetime.now()
+    task_manager = get_task_manager()
+    current_task_manager.set(task_manager)
+    current_work_dir.set(work_dir)
     worker_instance = BrokerWorker(goal, tools, work_dir, cache_messages, broker, mcp_manager, task_manager, kgm)
     result = await worker_instance.run()
     end_time = datetime.now()
@@ -21,6 +24,8 @@ async def worker(goal: str, tools: List[Union[str, Dict]], work_dir: str, cache_
 @register_tool()
 async def worker_gen(goal: str, tools: List[Union[str, Dict]], work_dir: str, cache_messages: Union[bool, List[Dict]] = None):
     start_time = datetime.now()
+    task_manager = get_task_manager()
+    current_task_manager.set(task_manager)
     worker_instance = BrokerWorker(goal, tools, work_dir, cache_messages, broker, mcp_manager, task_manager, kgm)
     async for result in worker_instance.stream_run():
         yield result
@@ -32,6 +37,8 @@ async def worker_gen(goal: str, tools: List[Union[str, Dict]], work_dir: str, ca
 @register_tool()
 async def chatgroup(tools: List[Union[str, Dict]], work_dir: str, cache_messages: Union[bool, List[Dict]] = None):
     start_time = datetime.now()
+    task_manager = get_task_manager()
+    current_task_manager.set(task_manager)
     worker_instance = ChatGroupWorker(tools, work_dir, cache_messages, broker, mcp_manager, task_manager, kgm)
     result = await worker_instance.run()
     end_time = datetime.now()
