@@ -37,7 +37,7 @@ def replace_xml_content(original_string: str, tag_name: str, replacement_content
 
 import io
 import base64
-from .aient.src.aient.core.utils import get_image_message, get_text_message
+from .aient.aient.core.utils import get_image_message, get_text_message
 
 async def get_current_screen_image_message(prompt):
     print("instruction agent 正在截取当前屏幕...")
